Module methods

Module methods 

Capability method parsing and validation for impl blocks

Valid signatures:

  • fn method_name(&self, client: &ClientType, ...args) -> ReturnType
  • fn method_name(&mut self, client: &ClientType, ...args) -> ReturnType
  • async fn method_name(&self, client: &ClientType, ...args) -> ReturnType

If an error type is defined, return types must be Result<T, ErrorType> or Result<T, Self::Error>

Structs

ImplMethod
Represents a validated method within a capability impl block.