bridgeable

Function bridgeable 

pub fn bridgeable(
    args: &BridgeableArgs,
    item: &mut ItemStruct,
    import_location: &Path,
) -> Result<TokenStream>
Attribute macro that adds rkyv serialization, the Bridgeable trait, and optionally the Documented trait for generating a JSON type spec.

Usage

#[bridgeable]                                     // bare minimum
#[bridgeable(Document)]                           // + Documented impl
#[bridgeable(derive(Debug, PartialEq))]           // + archived derives
#[bridgeable(derive(Debug, PartialEq), Document)] // all of the above