Module deep_ref

Module deep_ref 

Functions

deep_ref
Main function to generate the Deep Reference struct and implementation. Accepts a list of additional derives to apply to the generated struct.
deep_ref_rkyv
Specialized function for Rkyv. Generates the standard DeepRef stuff, PLUS an implementation for the Archived variant.