pub fn deep_ref(
input: &ItemStruct,
import_location: &Path,
derives_to_pass: &Vec<Ident>,
) -> Result<TokenStream>Expand description
Main function to generate the Deep Reference struct and implementation. Accepts a list of additional derives to apply to the generated struct.