pub fn create_ident(
import_location: Path,
meta: &str,
no_ffi: bool,
) -> TokenStreamExpand description
Creates a function we can use to register the library identity
pub fn create_ident(
import_location: Path,
meta: &str,
no_ffi: bool,
) -> TokenStreamCreates a function we can use to register the library identity