Capability method parsing and validation for impl blocks
Valid signatures:
fn method_name(&self, client: &ClientType, ...args) -> ReturnTypefn method_name(&mut self, client: &ClientType, ...args) -> ReturnTypeasync fn method_name(&self, client: &ClientType, ...args) -> ReturnType
If an error type is defined, return types must be Result<T, ErrorType> or Result<T, Self::Error>
Structs
- Impl
Method - Represents a validated method within a capability impl block.